Struct aws_sdk_computeoptimizer::model::LambdaFunctionMemoryRecommendationOption [−][src]
#[non_exhaustive]pub struct LambdaFunctionMemoryRecommendationOption {
pub rank: i32,
pub memory_size: i32,
pub projected_utilization_metrics: Option<Vec<LambdaFunctionMemoryProjectedMetric>>,
}Expand description
Describes a recommendation option for an Lambda function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rank: i32The rank of the function recommendation option.
The top recommendation option is ranked as 1.
memory_size: i32The memory size, in MB, of the function recommendation option.
projected_utilization_metrics: Option<Vec<LambdaFunctionMemoryProjectedMetric>>An array of objects that describe the projected utilization metrics of the function recommendation option.
Implementations
The rank of the function recommendation option.
The top recommendation option is ranked as 1.
The memory size, in MB, of the function recommendation option.
An array of objects that describe the projected utilization metrics of the function recommendation option.
Creates a new builder-style object to manufacture LambdaFunctionMemoryRecommendationOption