Struct aws_sdk_computeoptimizer::output::ExportEbsVolumeRecommendationsOutput [−][src]
#[non_exhaustive]pub struct ExportEbsVolumeRecommendationsOutput {
pub job_id: Option<String>,
pub s3_destination: Option<S3Destination>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_id: Option<String>The identification number of the export job.
Use the DescribeRecommendationExportJobs action, and specify the job ID to view the status of an export job.
s3_destination: Option<S3Destination>Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and object keys of a recommendations export file, and its associated metadata file.
Implementations
Creates a new builder-style object to manufacture ExportEbsVolumeRecommendationsOutput